@@ -28,12 +28,13 @@ ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 POSSIBILITY OF SUCH DAMAGE.
 """
 
+from os import F_OK, R_OK, W_OK, X_OK
 import glob as _glob
 import os as _os
 import shutil as _shutil
 import sys as _sys
 
-__all__ = ['Path']
+__all__ = ['Path', 'F_OK', 'R_OK', 'W_OK', 'X_OK']
 
 String = (str, unicode)
 native_glob = _glob.glob
@@ -44,7 +45,7 @@ system_sep = _os.path.sep
 
 pyver = float('%s.%s' % _sys.version_info[:2])
 
-version = 0, 73, 5
+version = 0, 77, 1
 
 class Path(object):
     """\
@@ -67,6 +68,23 @@ class Path(object):
         p = new_cls.__new__(new_cls, string, sep=sep)
         return p
 
+    @classmethod
+    def getcwd(cls):
+        return cls(_os.getcwd()) / ''
+
+    @classmethod
+    def getcwdu(cls):
+        return cls(_os.getcwdu()) / ''
+
+    @staticmethod
+    def glob(pattern):
+        return [Path(p) for p in native_glob(pattern)]
+
+    @staticmethod
+    def listdir(dir):
+        return [Path(p) for p in _os.listdir(dir)]
+
+
 methods = {}
 
 def vol(self):
@@ -146,8 +164,8 @@ def __new__(cls, string='', sep=None):
         string = string.replace(system_sep, SEP)
     if string == '.':
         string = './'
-    elif string == '..':
-        string = '../'
+    elif string == '..' or string.endswith('/..'):
+        string += '/'
     string = string.rstrip('.')
     sep = SEP
     if string[:2] == sep+sep:           # usually '//'
@@ -242,14 +260,15 @@ def __mul__(self, other):
         return NotImplemented
     other = self.__class__(other)
     if other._vol:
-        raise ValueError("Cannot combine %r and %r" % (self, other))
-    vol = self._vol
-    current = self._dirs
-    next = other._dirs
-    if current and next and next[0] == SEP:
-            dirs = current + next[1:]
+        vol = other._vol
+        current = ''
     else:
-        dirs = current + next
+        vol = self._vol
+        current = self._dirs
+    next = other._dirs
+    if next and next[0] == SEP:
+        current = ''
+    dirs = current + next
     new_path = []
     for dir in dirs.split(SEP):
         if dir not in ('.','..'):
@@ -339,12 +358,79 @@ def __sub__(self, other):
 methods['__sub__'] = __sub__
 del __sub__
 
-def copy(self, dst):
-    'thin wrapper around shutil.copy2'
+def access(self, mode, file_name=None):
+    if file_name is None:
+        return _os.access(self, mode)
+    else:
+        return _os.access(self/file_name, mode)
+methods['access'] = access
+del access
+
+def chdir(self, subdir=None):
+    if subdir is None:
+        subdir = self
+    else:
+        subdir = self/subdir
+    _os.chdir(subdir)
+    return Path.getcwd()
+methods['chdir'] = chdir
+del(chdir)
+
+if pyver >= 2.6:
+    def chflags(self, flags, files=None):
+        if files is None:
+            files = [self]
+        elif isinstance(files, (basestring, Path)):
+            files = self.glob(files)
+        for file in files:
+            _os.chflags(file, flags)
+    methods['chflags'] = chflags
+    del chflags
+
+def chmod(self, mode, files=None):
+    "thin wrapper around os.chmod"
+    if files is None:
+        files = [self]
+    elif isinstance(files, (basestring, Path)):
+        files = self.glob(files)
+    for file in files:
+        _os.chmod(file, mode)
+methods['chmod'] = chmod
+del chmod
+
+def chown(self, uid, gid, files=None):
+    "thin wrapper around os.chown"
+    if files is None:
+        files = [self]
+    elif isinstance(files, (basestring, Path)):
+        files = self.glob(files)
+    for file in files:
+        _os.chown(file, uid, gid)
+methods['chown'] = chown
+del chown
+
+def chroot(self):
+    return _os.chroot(self)
+methods['chroot'] = chroot
+del chroot
+
+def copy(self, files, dst=None):
+    """
+    thin wrapper around shutil.copy2  (files is optional)
+    """
+    if dst is None:
+        dst, files = files, dst
+    else:
+        dst = Path(dst) / ''
     if isinstance(dst, self.__class__):
         dst = self.base_cls(dst)
-    src = self.base_cls(self)
-    _shutil.copy2(src, dst)
+    if files is None:
+        files = [self]
+    elif isinstance(files, (basestring, Path)):
+        files = self.glob(files)
+    for file in files:
+        src = self.base_cls(file)
+        _shutil.copy2(src, dst)
 methods['copy'] = copy
 del copy
 
@@ -365,18 +451,6 @@ def count(self, sub, start=None, end=None):
 methods['count'] = count
 del count
 
-def chmod(self, mode):
-    "thin wrapper around os.chmod"
-    _os.chmod(self, mode)
-methods['chmod'] = chmod
-del chmod
-
-def chown(self, uid, gid):
-    "thin wrapper around os.chown"
-    _os.chown(self, uid, gid)
-methods['chown'] = chown
-del chown
-
 def endswith(self, suffix, start=None, end=None):
     if isinstance(suffix, String):
         new_suffix = suffix.replace(system_sep, SEP)
@@ -391,8 +465,11 @@ def endswith(self, suffix, start=None, end=None):
 methods['endswith'] = endswith
 del endswith
 
-def exists(self):
-    return _os.path.exists(self)
+def exists(self, file_name=None):
+    if file_name is None:
+        return _os.path.exists(self)
+    else:
+        return _os.path.exists(self/file_name)
 methods['exists'] = exists
 del exists
 
@@ -446,11 +523,52 @@ def ismount(self):
 methods['ismount'] = ismount
 del ismount
 
+if pyver >= 2.6:
+    def lchflags(self, flags, files=None):
+        if files is None:
+            files = [self]
+        elif isinstance(files, (basestring, Path)):
+            files = self.glob(files)
+        for file in files:
+            _os.chflags(file, flags)
+    methods['lchflags'] = lchflags
+    del lchflags
+
+def lchmod(self, mode, files=None):
+    if files is None:
+        files = [self]
+    elif isinstance(files, (basestring, Path)):
+        files = self.glob(files)
+    for file in files:
+        _os.lchmod(file, mode)
+methods['lchmod'] = lchmod
+del lchmod
+
+def lchown(self, uid, gid, files=None):
+    if files is None:
+        files = [self]
+    elif isinstance(files, (basestring, Path)):
+        files = self.glob(files)
+    for file in files:
+        _os.lchown(file, uid, gid)
+methods['lchown'] = lchown
+del lchown
+
+def link(self, new_name):
+    return _os.link(self, new_name)
+methods['link'] = link
+del link
+
 def listdir(self):
     return [Path(p) for p in _os.listdir(self)]
 methods['listdir'] = listdir
 del listdir
 
+def lstat(self):
+    return _os.lstat(self)
+methods['lstat'] = lstat
+del lstat
+
 def lstrip(self, chars=None):
     if chars is not None:
         chars = chars.replace(system_sep, SEP)
@@ -458,6 +576,11 @@ def lstrip(self, chars=None):
 methods['lstrip'] = lstrip
 del lstrip
 
+def mkfifo(self, mode):
+    return _os.mkfifo(self, mode)
+methods['mkfifo'] = mkfifo
+del mkfifo
+
 def mkdir(self, mode=None, owner=None):
     """
     Create a directory, setting owner if given.
@@ -467,7 +590,7 @@ def mkdir(self, mode=None, owner=None):
     else:
         _os.mkdir(self, mode)
     if owner is not None:
-        _os.chown(*owner)
+        _os.chown(self, *owner)
 methods['mkdir'] = mkdir
 del mkdir
 
@@ -484,16 +607,48 @@ def mkdirs(self, mode=None, owner=None):
 methods['mkdirs'] = mkdirs
 del mkdirs
 
-def move(self, dst):
-    'thin wrapper around shutil.move'
+def move(self, files, dst=None):
+    """
+    thin wrapper around shutil.move  (files is optional)
+    """
+    if dst is None:
+        files, dst = dst, files
+    else:
+        dst = Path(dst) / ''
     if isinstance(dst, self.__class__):
         dst = self.base_cls(dst)
-    src = self.base_cls(self)
-    print src, dst
-    _shutil.move(src, dst)
+    if files is None:
+        files = [self]
+    elif isinstance(files, (basestring, Path)):
+        files = self.glob(files)
+    for file in files:
+        src = self.base_cls(file)
+        _shutil.move(src, dst)
 methods['move'] = move
 del move
 
+def pathconf(self, name):
+    return _os.pathconf(self, name)
+methods['pathconf'] = pathconf
+del pathconf
+
+methods['pathconf_names'] = _os.pathconf_names
+
+def readlink(self):
+    return _os.readlink(self)
+methods['readlink'] = readlink
+del readlink
+
+def removedirs(self, directories=None):
+    if directories is None:
+        directories = [self]
+    elif isinstance(directories, (basestring, Path)):
+        directories = self.glob(directories)
+    for subdir in directories:
+        _os.removedirs(subdir)
+methods['removedirs'] = removedirs
+del removedirs
+
 def rename(self, dst):
     'thin wrapper around os.rename)'
     if isinstance(dst, self.__class__):
@@ -503,6 +658,11 @@ def rename(self, dst):
 methods['rename'] = rename
 del rename
 
+def renames(self, dst):
+    return _os.renames(self, dst)
+methods['renames'] = renames
+del renames
+
 def replace(self, old, new, count=None):
     old = old.replace(system_sep, SEP)
     new = new.replace(system_sep, SEP)
@@ -513,9 +673,14 @@ def replace(self, old, new, count=None):
 methods['replace'] = replace
 del replace
 
-def rmdir(self):
+def rmdir(self, directories=None):
     'thin wrapper around os.rmdir'
-    _os.rmdir(self)
+    if directories is None:
+        directories = [self]
+    elif isinstance(directories, (basestring, Path)):
+        directions = self.glob(directories)
+    for subdir in directories:
+        _os.rmdir(subdir)
 methods['rmdir'] = rmdir
 del rmdir
 
@@ -552,11 +717,19 @@ def startswith(self, prefix, start=None, end=None):
 methods['startswith'] = startswith
 del startswith
 
-def stat(self):
-    return _os.stat(self)
+def stat(self, file_name=None):
+    if file_name is None:
+        return _os.stat(self)
+    else:
+        return _os.stat(self/file_name)
 methods['stat'] = stat
 del stat
 
+def statvfs(self):
+    return _os.statvfs(self)
+methods['statvfs'] = statvfs
+del statvfs
+
 def strip(self, chars=None):
     if chars is not None:
         chars = chars.replace(system_sep, SEP)
@@ -572,13 +745,37 @@ def strip_ext(self, remove=1):
 methods['strip_ext'] = strip_ext 
 del strip_ext
 
-def unlink(self):
+def symlink(self, new_name):
+    return _os.symlink(self, new_name)
+methods['symlink'] = symlink
+del symlink
+
+def unlink(self, files=None):
     "thin wrapper around os.unlink"
-    _os.unlink(self)
+    if files is None:
+        files = [self]
+    elif isinstance(files, (basestring, Path)):
+        files = self.glob(files)
+    for target in files:
+        _os.unlink(target)
 methods['unlink'] = unlink
 methods['remove'] = unlink
 del unlink
 
+def utime(self, files, times=None):
+    """
+    files is optional
+    """
+    if times is None:
+        times = files
+        files = [self]
+    elif isinstance(files, (basestring, Path)):
+        files = self.glob(files)
+    for file in files:
+        _os.utime(file, times)
+methods['utime'] = utime
+del utime
+
 if pyver < 2.6:
     def walk(self, topdown=True, onerror=None):
         p = self.__class__
